@@ -2,6 +2,15 @@ MCMCsamp <- function(object, mcmc = 1L, verbose = NULL, ...) UseMethod("MCMCsamp
 # from lme4/R/AllGeneric.R
 MCMCsamp.spautolm <- function(object, mcmc = 1L, verbose = NULL, ...,
     burnin=0L, scale=1, listw, control=list()) {
+#    warning("Method MCMCsamp moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(MCMCsamp(object=object, mcmc = mcmc, verbose = verbose, ...,
+#    burnin=burnin, scale=scale, listw=listw, control=control))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     con <- list(Imult=2, cheb_q=5, MC_p=16, MC_m=30, super=NULL,
         spamPivot="MMD", in_coef=0.1, type="MC",
         correct=TRUE, trunc=TRUE, SE_method="LU", nrho=200,
@@ -79,9 +88,19 @@ MCMCsamp.spautolm <- function(object, mcmc = 1L, verbose = NULL, ...,
     attr(res, "timings") <- do.call("rbind", timings)[, c(1, 3)]
     res
 }
+#}
 
 MCMCsamp.sarlm <- function(object, mcmc = 1L, verbose = NULL, ...,
     burnin=0L, scale=1, listw, listw2=NULL, control=list()) {
+#    warning("Method MCMCsamp.sarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(MCMCsamp(object=object, mcmc = mcmc, verbose = verbose, ...,
+#    burnin=burnin, scale=scale, listw=listw, listw2=listw2, control=control))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     timings <- list()
     .ptime_start <- proc.time()
     con <- list(compiled_sse=FALSE, Imult=2, cheb_q=5, MC_p=16, MC_m=30,
@@ -243,4 +262,5 @@ MCMCsamp.sarlm <- function(object, mcmc = 1L, verbose = NULL, ...,
         warning("MCMCsamp: very low acceptance rate")
     res
 }
+#}
 
