@@ -10,26 +10,28 @@
 #include <R_ext/Utils.h>
 #define ROFFSET 1
 
-SEXP opt_error_free(SEXP ptr);
-SEXP hess_error_free(SEXP ptr);
-SEXP hess_lag_free(SEXP ptr);
-SEXP opt_error_init();
-SEXP hess_error_init();
-SEXP hess_lag_init();
-SEXP R_ml_sse_env(SEXP env, SEXP coef);
-SEXP R_ml1_sse_env(SEXP env, SEXP lambda, SEXP beta);
-SEXP R_ml2_sse_env(SEXP env, SEXP rho, SEXP beta);
-SEXP mom_calc_int2(SEXP is, SEXP m, SEXP nb, SEXP weights, SEXP card);
+SEXP opt_error_free(SEXP ptr); // deprecated
+SEXP hess_error_free(SEXP ptr); // deprecated
+SEXP hess_lag_free(SEXP ptr); // deprecated
+SEXP opt_error_init(); // deprecated
+SEXP hess_error_init(); // deprecated
+SEXP hess_lag_init(); // deprecated
+SEXP R_ml_sse_env(SEXP env, SEXP coef); // deprecated
+SEXP R_ml1_sse_env(SEXP env, SEXP lambda, SEXP beta); // deprecated
+SEXP R_ml2_sse_env(SEXP env, SEXP rho, SEXP beta); // deprecated
+SEXP mom_calc_int2(SEXP is, SEXP m, SEXP nb, SEXP weights, SEXP card); // deprecated
 
-void opt_error_set(SEXP env);
-void hess_error_set(SEXP env);
-void hess_lag_set(SEXP env);
+void opt_error_set(SEXP env); // deprecated
+void hess_error_set(SEXP env); // deprecated
+void hess_lag_set(SEXP env); // deprecated
 
 SEXP card(SEXP nb);
-SEXP listw2dsT(SEXP nbs, SEXP wts, SEXP card, SEXP ncard2);
-SEXP listw2dgR(SEXP nbs, SEXP wts, SEXP card, SEXP ncard);
+SEXP listw2dsT(SEXP nbs, SEXP wts, SEXP card, SEXP ncard2); // deprecated
+SEXP listw2dgR(SEXP nbs, SEXP wts, SEXP card, SEXP ncard); // deprecated
 SEXP listw2sn(SEXP nbs, SEXP wts, SEXP card, SEXP ncard);
 SEXP dnearneigh(SEXP din1, SEXP din2, SEXP pnte, SEXP p, SEXP test, SEXP lonlat);
+SEXP dnearneigh1(SEXP din1, SEXP din2, SEXP pnte, SEXP test, SEXP cands);
+
 SEXP gearyw(SEXP nb, SEXP weights, SEXP x, SEXP card, SEXP zeropolicy, SEXP ftype);
 SEXP gsymtest(SEXP nb, SEXP glist, SEXP card);
 SEXP spInsiders(SEXP bbbi, SEXP bbbj);
@@ -43,16 +45,15 @@ SEXP poly_loop2(SEXP n, SEXP i_findInBox, SEXP bb, SEXP pl, SEXP nrs, SEXP dsnap
 SEXP symtest(SEXP nb, SEXP card, SEXP verbose);
 SEXP g_components(SEXP nblst, SEXP cmpnm);
 SEXP lmin21(SEXP nb, SEXP y, SEXP cy, SEXP card);
-SEXP lmin22(SEXP nb, SEXP y, SEXP cy, SEXP card, SEXP beta);
-SEXP lmin23(SEXP nb, SEXP y, SEXP cy, SEXP card, SEXP beta, SEXP tol);
-SEXP lmin3(SEXP nb, SEXP ev1, SEXP ev1_lag, SEXP n_nei, SEXP beta, SEXP tol);
-SEXP lmin3S(SEXP nb, SEXP ev1, SEXP ev1_lag, SEXP n_nei, SEXP card, SEXP beta, SEXP tol);
+SEXP lmin22(SEXP nb, SEXP y, SEXP cy, SEXP card, SEXP beta); // deprecated
+SEXP lmin23(SEXP nb, SEXP y, SEXP cy, SEXP card, SEXP beta, SEXP tol); // deprecated
+SEXP lmin3(SEXP nb, SEXP ev1, SEXP ev1_lag, SEXP n_nei, SEXP beta, SEXP tol); // deprecated
+SEXP lmin3S(SEXP nb, SEXP ev1, SEXP ev1_lag, SEXP n_nei, SEXP card, SEXP beta, SEXP tol); // deprecated
 
 void dfs(SEXP nblst, SEXP cmpnm, SEXP visited, int curcmp, int nodeid);
 void compute_gabriel(int *no_nodes, int *g1, int *g2, int *nogab, int *ngaballoc,  double *nodes_xd, double *nodes_yd);
 void compute_relative(int *no_nodes, int *g1, int *g2, int *nogab, int *ngaballoc, double *nodes_xd, double *nodes_yd);
 void prunemst(int *e1, int *e2, int *ne, int *gr);
-void compute_soi(int *no_nodes, int *g1, int *g2, int *noedges, int *noneigh, int *neigh, int *nearneigh, double *rad, double *nodes_xd, double *nodes_yd);
 
 void gcdist(double *lon1, double *lon2, double *lat1, double *lat2, double *dist);
 void knearneigh(int *kin, int *pnte, int *p, double *test, int *res, double *dists, int *lonlat);
